summaryrefslogtreecommitdiffstats
path: root/kopete/libkopete/kopetecontactlist.h
diff options
context:
space:
mode:
Diffstat (limited to 'kopete/libkopete/kopetecontactlist.h')
-rw-r--r--kopete/libkopete/kopetecontactlist.h66
1 files changed, 33 insertions, 33 deletions
diff --git a/kopete/libkopete/kopetecontactlist.h b/kopete/libkopete/kopetecontactlist.h
index fc6dd5f9..405abb79 100644
--- a/kopete/libkopete/kopetecontactlist.h
+++ b/kopete/libkopete/kopetecontactlist.h
@@ -19,8 +19,8 @@
#ifndef KOPETECONTACTLIST_H__
#define KOPETECONTACTLIST_H__
-#include <qobject.h>
-#include <qptrlist.h>
+#include <tqobject.h>
+#include <tqptrlist.h>
#include "kopete_export.h"
@@ -62,7 +62,7 @@ public:
/**
* @brief return a list of all metacontact of the contactlist
* Retrieve the list of all available meta contacts.
* The returned QPtrList is not the internally used variable, so changes
* to it won't propagate into the actual contact list. This can be
* useful if you need a subset of the contact list, because you can
* simply filter the result set as you wish without worrying about
@@ -70,18 +70,18 @@ public:
* The contained MetaContacts are obviously _not_ duplicates, so
* changing those *will* have the expected result :-)
*/
- QPtrList<MetaContact> metaContacts() const;
+ TQPtrList<MetaContact> metaContacts() const;
/**
* @return all groups
*/
- QPtrList<Group> groups() const;
+ TQPtrList<Group> groups() const;
/**
* Return the metacontact referenced by the given id. is none is found, return 0L
* @sa MetaContact::metaContactId()
*/
- MetaContact *metaContact( const QString &metaContactId ) const;
+ MetaContact *metaContact( const TQString &metaContactId ) const;
/**
* return the group with the given unique id. if none is found return 0L
@@ -97,17 +97,17 @@ public:
* @param contactId the @ref Contact::contactId()
* @return the contact with the parameters, or 0L if not found.
*/
- Contact *findContact( const QString &protocolId, const QString &accountId, const QString &contactId ) const;
+ Contact *findContact( const TQString &protocolId, const TQString &accountId, const TQString &contactId ) const;
/**
* Find a contact by display name. Returns the first match.
*/
- MetaContact *findMetaContactByDisplayName( const QString &displayName ) const;
+ MetaContact *findMetaContactByDisplayName( const TQString &displayName ) const;
/**
* Find a meta contact by its contact id. Returns the first match.
*/
- MetaContact *findMetaContactByContactId( const QString &contactId ) const;
+ MetaContact *findMetaContactByContactId( const TQString &contactId ) const;
/**
* @brief find a group with his displayName
@@ -117,17 +117,17 @@ public:
* @param type is the Group::GroupType to search, the default value is group::Normal
* @return always a valid Group
*/
- Group * findGroup( const QString &displayName, int type = 0/*Group::Normal*/ );
+ Group * findGroup( const TQString &displayName, int type = 0/*Group::Normal*/ );
/**
* return the list of metacontact actually selected in the contactlist UI
*/
- QPtrList<MetaContact> selectedMetaContacts() const;
+ TQPtrList<MetaContact> selectedMetaContacts() const;
/**
* return the list of groups actualy selected in the contactlist UI
*/
- QPtrList<Group> selectedGroups() const ;
+ TQPtrList<Group> selectedGroups() const ;
/**
* return the metacontact that represent the user itself.
@@ -171,7 +171,7 @@ public slots:
* This method has to be called by the contactlist UI side.
* it stores the selected items, and emits signals
*/
- void setSelectedItems(QPtrList<MetaContact> metaContacts , QPtrList<Group> groups);
+ void setSelectedItems(TQPtrList<MetaContact> metaContacts , TQPtrList<Group> groups);
/**
* Apply the global identity.
@@ -204,7 +204,7 @@ signals:
/**
* A group has just been renamed
*/
- void groupRenamed(Kopete::Group *, const QString & oldname);
+ void groupRenamed(Kopete::Group *, const TQString & oldname);
/**
* A contact has been added to a group
@@ -217,7 +217,7 @@ signals:
/**
* This signal is emit when the selection has changed, it is emitted after the following slot
- * Warning: Do not delete any contacts in slots connected to this signal. (it is the warning in the QListView::selectionChanged() doc)
+ * Warning: Do not delete any contacts in slots connected to this signal. (it is the warning in the TQListView::selectionChanged() doc)
*/
void selectionChanged();
/**
@@ -231,7 +231,7 @@ signals:
* This signal is emitted each time a global identity field change.
* HOWTO use:
*
* - Connect signal globalIdentityChanged(const QString &key, const QVariant
* &value) to a slot in your derivate Account class (the best
* place to put it).
* - In the slot:
@@ -242,12 +242,12 @@ signals:
*
* Connect signal in your Account constructor:
* @code
- * connect(Kopete::ContactList::self(), SIGNAL(globalIdentityChanged(const QString&, const QVariant&)), SLOT(slotglobalIdentityChanged(const QString&, const QVariant&)));
+ * connect(Kopete::ContactList::self(), TQT_SIGNAL(globalIdentityChanged(const TQString&, const TQVariant&)), TQT_SLOT(slotglobalIdentityChanged(const TQString&, const TQVariant&)));
* @endcode
*
* Example of a typical implemented slot:
* @code
* void slotGlobalIdentityChanged(const QString &key, const QVariant &value)
* {
* if(key == Kopete::Global::Properties::self()->nickName().key())
* {
@@ -262,7 +262,7 @@ signals:
* }
* @endcode
*/
- void globalIdentityChanged( const QString &key, const QVariant &value );
+ void globalIdentityChanged( const TQString &key, const TQVariant &value );
private slots:
/**
@@ -289,7 +289,7 @@ private:
/**
* Convert the contact list from an older version
*/
- void convertContactList( const QString &fileName, uint fromVersion, uint toVersion );
+ void convertContactList( const TQString &fileName, uint fromVersion, uint toVersion );
/**
@@ -305,41 +305,41 @@ public: //TODO I think all theses method should be moved to the decop interface.
/**
* Return all meta contacts
*/
- QStringList contacts() const;
+ TQStringList contacts() const;
/**
* Return all meta contacts that are reachable
*/
- QStringList reachableContacts() const;
+ TQStringList reachableContacts() const;
/**
* Return all contacts that are online
*/
- QPtrList<Contact> onlineContacts() const;
+ TQPtrList<Contact> onlineContacts() const;
/**
* Overloaded method of @ref onlineContacts() that only returns
* the online contacts for a single protocol
*/
- QPtrList<Contact> onlineContacts( const QString &protocolId ) const;
+ TQPtrList<Contact> onlineContacts( const TQString &protocolId ) const;
/**
* Return all meta contacts that are online
*/
- QPtrList<MetaContact> onlineMetaContacts() const;
+ TQPtrList<MetaContact> onlineMetaContacts() const;
/**
* Overloaded method of @ref onlineMetaContacts() that only returns
* the online meta contacts for a single protocol
*/
- QPtrList<MetaContact> onlineMetaContacts( const QString &protocolId ) const;
+ TQPtrList<MetaContact> onlineMetaContacts( const TQString &protocolId ) const;
/**
* Returns all contacts which can accept file transfers
*/
- QStringList fileTransferContacts() const;
+ TQStringList fileTransferContacts() const;
- QStringList contactFileProtocols( const QString &displayName);
+ TQStringList contactFileProtocols( const TQString &displayName);
/**
* Return all meta contacts with their current status
@@ -347,7 +347,7 @@ public: //TODO I think all theses method should be moved to the decop interface.
* FIXME: Do we *need* this one? Sounds error prone to me, because
* nicknames can contain parentheses too. - Martijn
*/
- QStringList contactStatuses() const;
+ TQStringList contactStatuses() const;
/**
@@ -361,13 +361,13 @@ public: //TODO I think all theses method should be moved to the decop interface.
* @param altFileName (Optional) An alternate filename for the file we are sending
* @param fileSize (Optional) The size of the file
*/
- void sendFile(const QString &displayName, const KURL &sourceURL,
- const QString &altFileName = QString::null, const long unsigned int fileSize = 0L);
+ void sendFile(const TQString &displayName, const KURL &sourceURL,
+ const TQString &altFileName = TQString::null, const long unsigned int fileSize = 0L);
/**
* Open a chat to a contact, and optionally set some initial text
*/
- void messageContact( const QString &displayName, const QString &messageText = QString::null );
+ void messageContact( const TQString &displayName, const TQString &messageText = TQString::null );
public slots:
/**
@@ -384,7 +384,7 @@ private:
/**
* Return a XML representation of the contact list
*/
- const QDomDocument toXML();
+ const TQDomDocument toXML();
/**
* Load the contact list from XML file
@@ -62,7 +62,7 @@ public:
* @brief return a list of all metacontact of the contactlist
* Retrieve the list of all available meta contacts.
- * The returned QPtrList is not the internally used variable, so changes
+ * The returned TQPtrList is not the internally used variable, so changes
* to it won't propagate into the actual contact list. This can be
* useful if you need a subset of the contact list, because you can
@@ -231,7 +231,7 @@ signals:
* HOWTO use:
*
- * - Connect signal globalIdentityChanged(const QString &key, const QVariant
+ * - Connect signal globalIdentityChanged(const TQString &key, const TQVariant
* &value) to a slot in your derivate Account class (the best
* place to put it).
@@ -242,12 +242,12 @@ signals:
* Example of a typical implemented slot:
* @code
- * void slotGlobalIdentityChanged(const QString &key, const QVariant &value)
+ * void slotGlobalIdentityChanged(const TQString &key, const TQVariant &value)
* {
* if(key == Kopete::Global::Properties::self()->nickName().key())